% LaTeX Template für die Verfasste Studierendenschaft

% Copyright © 2022 Valentin Weber
% Copyright © 2022 Justin Dretvic

% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

% The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{protocol_generic}[2022-07-05 Protocol LaTeX Class]

\LoadClass[a4paper,10pt, titlepage]{article}

% ---------================ Allgemeine Pakete ================---------
\RequirePackage{listings}                % Für Codesippets
\RequirePackage[ngerman]{babel}          % Dokumentsprache setzten
\RequirePackage[german=quotes]{csquotes} % Anführungsstriche einheitlich und leicht änderbar
\RequirePackage{graphicx}                % Einbinden von Bildern
\RequirePackage{svg}                     % Einbinden von svg Dateien
\graphicspath{ {./images/} }

\RequirePackage{fancyhdr}                % Header weitere Anpassungen
\RequirePackage{xcolor}                  % Farben 'x' ist neuer und unterstützt 'RGB' (0-255)
\RequirePackage[ddmmyyyy]{datetime}        % Erweiterte einstellungen des Datums
\renewcommand{\dateseparator}{.}        % Punkttrennung des Datums
\RequirePackage{booktabs}
\RequirePackage{calc}
\RequirePackage{wasysym}

% ---------================ Seitenränder ================---------
\RequirePackage{geometry}
\geometry{
    a4paper,
    top=25mm,
    bottom=25mm,
    left=25mm,
    right=20mm,
}

% ---------================ Schrift ================---------
% Schriftart / Font
\RequirePackage{fontspec}
\newfontfamily{\UniversCondensed}{UniversCondensed}[%
    Extension = .ttf,%
    Path = fonts/,%
    BoldFont = *-bold]
\newfontfamily{\LiberationSans}{LiberationSansNarrow}[%
    Extension = .ttf,%
    Path = fonts/,%
    UprightFont=*-Regular,%
    BoldFont=*-Bold,%
    ItalicFont=*-Italic,%
    BoldItalicFont=*-BoldItalic]
\setmainfont{LiberationSansNarrow}
% ACHTUNG: Arial darf aus Lizenzgründen *nicht* genutzt werden!

% Zeilenabstand
\RequirePackage{setspace}
\singlespacing                                    % 1 Zeilenabstand



% ---------================ Farben ================---------
\definecolor{headerColor}{RGB}{128,128,128}        % Farbe des Headers


% ---------================ Kopfzeile ================---------
% Linie in grau
\let\oldheadrule\headrule% Copy \headrule into \oldheadrule

\renewcommand{\headrule}{\color{headerColor}\oldheadrule}

\rhead{\fontsize{10}{0}\selectfont \textcolor{headerColor}{Seite \thepage}}
\lhead{\fontsize{10}{0}\selectfont \textcolor{headerColor}{\arabic{@sitzung}. Sitzung des {\@gremium} im \@semester}}
\pagestyle{fancy}



% ---------================ Formatierung ================---------
% Einrückungen von Aufzählungen wird angemessen berechnet
%\setlist[itemize]{leftmargin=*}
% Aufzählung auf '-' Symbol ändern
\def\labelitemi{--}
% Zeilenbstand bei Aufzählungen
%\setlist[enumerate]{itemsep=0mm}
%\setlist[itemize]{itemsep=0mm}
\setlength{\parindent}{0em}
\setlength{\parskip}{1ex plus 0.5ex minus 0.2ex}
\renewcommand\section{\@startsection {section}{1}{\z@}%
    {-3.5ex \@plus -1ex \@minus -.2ex}%
    {2.3ex \@plus.2ex}%
    {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
    {-3.25ex\@plus -1ex \@minus -.2ex}%
    {1.5ex \@plus .2ex}%
    {\normalfont\large\bfseries}}

% ---------================ Formatierung - Table of Contents ================---------

\RequirePackage{tocloft}
\cftsetindents{section}{0em}{2em}
\cftsetindents{subsection}{0em}{2em}
\renewcommand\cfttoctitlefont{\hfill\Large\bfseries}
\renewcommand\cftaftertoctitle{\hfill\mbox{}}
\renewcommand{\contentsname}{Agenda}

% ---------================ Hilfreiche Commands ================---------
\newcommand{\abstimmung}[4]{%
    \begin{tabular}{p{4cm} p{\textwidth-4\tabcolsep-4cm}}
    \toprule
    \multicolumn{2}{c}{\textbf{Abstimmung}} \\
    \midrule
    Abstimmungsfrage & #1 \\
    Dafür & #2 Stimmen \\
    Dagegen & #3 Stimmen \\
    Enthaltung & #4 Stimmen \\
    \bottomrule
    \end{tabular}}

\newenvironment{personenwahl}[3]{%
    \begin{tabular}{p{4cm} p{\textwidth-4\tabcolsep-4cm}}
    \toprule
    \multicolumn{2}{c}{\textbf{Wahl}} \\
    \midrule
    Amt & #1 \\
    gültige Stimmen & #2 \\
    ungültige Stimmen & #3 \\
    }{%
    \bottomrule
    \end{tabular}}


\newcommand{\checkbox}[1]{
    \ifthenelse{\equal{#1}{}}{\raisebox{.20ex}{\Square}}{\raisebox{.20ex}{\XBox}}}

\newcommand{\speaker}[2]{\textbf{#1: }#2\par}

\newcommand{\signature}{
    \vspace{40pt}
    \parbox{\textwidth}{
        \parbox{7cm}{
            \rule{7cm}{1pt}\\
            Vorsitz der \naechsteSitzung
        }
        \hfill
    }}

\newcommand{\vorherigeSitzung}{\arabic{@sitzungV}. Sitzung}
\newcommand{\naechsteSitzung}{\arabic{@sitzungN}. Sitzung}

\newcommand{\sessionstart}[1]{\noindent\normalfont\large\textbf{Beginn:} #1}
\newcommand{\sessionend}[1]{\noindent\normalfont\large\textbf{Schluss:} #1}
\newcommand{\sessionbreak}[2]{\noindent\normalfont\large\textbf{Pause:} #1 -- #2}


% ---------================ Variablen ================---------
\newcommand{\semester}[1]{\def\@semester{#1}}
\newcommand{\gremium}[1]{\def\@gremium{#1}}
\newcommand{\ort}[1]{\def\@ort{#1}}
\newcounter{@sitzung}
\newcounter{@sitzungN}
\newcounter{@sitzungV}
\newcommand{\sitzung}[1]{%
    \setcounter{@sitzung}{#1}%
    \setcounter{@sitzungN}{#1}%
    \setcounter{@sitzungV}{#1}%
    \addtocounter{@sitzungN}{1}%
    \addtocounter{@sitzungV}{-1}%
}
\newcommand{\datum}[1]{\def\@datum{#1}}
\newcommand{\uhrzeit}[1]{\def\@uhrzeit{#1}}
\newcommand{\schriftfuehrung}[1]{\def\@schriftfuehrung{#1}}
\newcommand{\vorsitz}[1]{\def\@vorsitz{#1}}
\newcommand{\mitglieder}[1]{\def\@mitglieder{#1}}
\newcommand{\sachverstaendige}[1]{\def\@sachverstaendige{#1}}

\newcommand{\@headerimage}{{\raggedleft \vspace{2cm}}}

\title{\arabic{@sitzung}. Sitzung des {\@gremium} im \@semester}

\setcounter{tocdepth}{2}

\renewcommand{\maketitle}{
    \begin{titlepage}
        % =============== ÜBERSCHRIFT UND LOGO
        \parbox[][][c]{0.69\textwidth}{
            \raggedright{\fontsize{22.5}{25}\selectfont {\UniversCondensed\textbf{Protokoll}}} \\
            \vspace{1em}
            {\arabic{@sitzung}. Sitzung | \@semester}
        }
        \parbox[][][c]{0.29\textwidth}{\@headerimage}\hfill
        \vspace{0.5em}
        \rule{\textwidth}{1pt}\hfill
        % =============== SITZUNGSDATEN
        \renewcommand{\arraystretch}{1.5}

        \begin{tabular}{p{3cm} p{1\textwidth-4\tabcolsep-3cm}}
            \textbf{Gremium:           } & \@gremium \\
            \textbf{Termin:            } & \@datum \\
            \textbf{Zeit:              } & \@uhrzeit \\
            \textbf{Ort:               } & \@ort \\
            \textbf{Mitglieder:        } & \parbox[t]{1\linewidth}{\@mitglieder}\\
            \textbf{Sachverständige:   } & \parbox[t]{1\linewidth}{\@sachverstaendige} \\
            \textbf{Schriftführung:    } & \@schriftfuehrung \\
            \textbf{Vorsitz:           } & \@vorsitz \\
        \end{tabular}
        
        \@thanks
        \rule{\textwidth}{1pt}\hfill
        
        \tableofcontents
        \vfil
        \null
    \end{titlepage}
    \setcounter{footnote}{0}
    \global \let \thanks \relax
    \global \let \maketitle \relax
    \global \let \@thanks \@empty
    \global \let \@author \@empty
    \global \let \@date \@empty
    \global \let \@title \@empty
    \global \let \title \relax
    \global \let \author \relax
    \global \let \date \relax
    \global \let \and \relax}