% LaTeX Template für die Verfasste Studierendenschaft

% Copyright © 2022 Valentin Weber
% Copyright © 2022 Justin Dretvic

% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

% The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{documents_generic}[2022-07-05 Protocol LaTeX Class]

\LoadClass[a4paper,10pt]{article}

% ##################################################
% Allgemeine Pakete
% ##################################################

\RequirePackage[ngerman]{babel} % this is needed for german umlauts

\RequirePackage{graphicx} % nutze Graphiken
\RequirePackage{svg} % nutze svg Dateien

\RequirePackage{forloop}

% ##################################################
% Generic Packges
% ##################################################

\RequirePackage{array} 
\RequirePackage{booktabs}

\RequirePackage{multirow} % benutze zwei Reihen als eine
\RequirePackage{wasysym} % for \Square \CheckedBox \XBox
\RequirePackage{enumitem} % remove indent in itemize

% ##################################################
% Seitenränder
% ##################################################

\RequirePackage{geometry}
\geometry{
	a4paper,
	top=20mm,
	bottom=10mm,
	left=20mm,
	right=20mm,
	%showframe,
}


% ##################################################
% Schrift
% ##################################################

\RequirePackage{xltxtra} %???
\defaultfontfeatures{Ligatures=TeX}

% Wahlmöglichkeit: Entweder Arial Narrow oder Liberation Sans Narrow als Font auswählen!
\setmainfont{Liberation Sans Narrow}
%\setmainfont{Arial Narrow}

%\RequirePackage{fontspec}
%\setmainfont[
%	BoldFont={Arial Bold}, 
%	ItalicFont={Arial Italic},
%	BoldItalicFont={Arial Bold Italic}
%	]{Arial}
%\newfontfamily{\UniversCondensed}{UniversCondensedBold}[Extension = .ttf, Path = fonts/]

% Zeilenabstand
\RequirePackage{setspace}
\singlespacing % 1 Zeilenabstand	

% ##################################################
% Header und Footer
% ##################################################

\RequirePackage{lastpage} % count pages for footer
\RequirePackage{fancyhdr} % header and footer
\pagestyle{fancy}
\fancyhf{}
\setlength{\headsep}{1em}
\setlength{\footskip}{1em}
%\setlength{\headheight}{0pt} 
%\setlength{\footheight}{0pt} 
%\renewcommand{\headrulewidth}{0pt}
\lhead{\fontsize{10}{0}\selectfont \textcolor{headerColor}{\@docheadertext}}
\rhead{
    \textcolor{headerColor}{Seite \thepage \hspace{1pt} von \pageref{LastPage}}
}


% ##################################################
% Tabellen
% ##################################################

\RequirePackage{multirow}
\RequirePackage{hhline}
\RequirePackage{multicol}


% ##################################################
% Farben
% ##################################################


\RequirePackage{xcolor}                         % Farben 'x' ist neuer und unterstützt 'RGB' (0-255)
\RequirePackage{colortbl}                       % Farben im tabular

\definecolor{headerColor}{RGB}{128,128,128}		% Farbe des Headers
\definecolor{lightgrey}{RGB}{240,240,240}

\definecolor{astagreen}{RGB}{128,186, 39}
\definecolor{astablue}{RGB}{0,60,80}
\definecolor{vstgreen}{RGB}{0,132,77}

\definecolor{blue}{RGB}{0,0,255}
\definecolor{red}{RGB}{255,0,0}
\definecolor{green}{RGB}{0,255,0}
\definecolor{yellow}{RGB}{255,255,0}
\definecolor{blue}{RGB}{255,165,0}

\RequirePackage{tcolorbox}[most]                % farbige Boxen
\tcbset{
    center title,
    left=0pt,
    right=0pt,
    top=0pt,
    bottom=0pt,
    width=\dimexpr\textwidth\relax,
    enlarge left by=0mm,
    boxsep=5pt,
    arc=0pt,
    outer arc=0pt,
}

% ##################################################
% Document Variables
% ##################################################

\newcommand{\docpdfauthor}[1]{\def\docpdfauthor{#1}}
\newcommand{\docpdftitle}[1]{\def\@docpdftitle{#1}}
\newcommand{\docheadertext}[1]{\def\@docheadertext{#1}}
\newcommand{\formtitletext}[1]{\def\@formtitletext{#1}}

\RequirePackage[hidelinks,pdfversion=2.0]{hyperref} % needed for forms and links within the text
%\hypersetup{
%    pdfauthor={\@docpdfauthor},
%    pdftitle=\@docpdftitle
%}

\newcommand{\formtitle}[1]{
    \parbox[][][c]{0.69\textwidth}{\raggedright{\LARGE \@formtitletext}}
    \parbox[][][c]{0.29\textwidth}{\raggedleft\includesvg[width=4cm]{images/#1_logo_farbe.svg}}\hfill
    \vspace{0.5em}
    \rule{\textwidth}{1pt}\hfill
}

\newcounter{@signdate} 
\setcounter{@signdate}{0} 
% \arabic{@signdate} % \addtocounter{@signdate}{1}
\newcounter{@signname} 
\setcounter{@signname}{0}
% \arabic{@signname} % \addtocounter{@signname}{1}

% ##################################################
% Custom Commands
% ##################################################

\RequirePackage{documents_functions}
